@@ -95,7 +95,9 @@ TopLevel::TopLevel(const KAboutData *aboutData, const QString &icon, QWidget *pa
     action->setText(i18n( "&Anonymous..." ) );
     connect(action, &QAction::triggered, this, &TopLevel::showTimeEditDialog);
 
-    m_helpMenu = new KHelpMenu( 0, *aboutData, false );
+    m_helpMenu = new KHelpMenu( nullptr, *aboutData, false );
+
+    setContextMenu(new QMenu);
 
     loadTeaMenuItems();
     contextMenu()->addSeparator();
@@ -185,7 +187,6 @@ void TopLevel::setTeaList(const QList<Tea> &tealist) {
 void TopLevel::loadTeaMenuItems() {
     int i=0;
 
-    setContextMenu(new QMenu);
     foreach(const Tea &t, m_tealist) {
         QAction *a = contextMenu()->addAction(
                    i18nc( "%1 - name of the tea, %2 - the predefined time for "
